@@ -21,3 +21,11 @@
 getTZ <- function() {
     .pkgenv$tz
 }
+
+setTZ <- function(tz) {
+    assign("tz", tz, envir=.pkgenv)
+}
+
+isRStudio <- function() {
+    .pkgenv$isRStudio
+}
