@@ -64,4 +64,8 @@ anytime("NA") 				# String NA
 anytime(Sys.time())                     # POSIXt pass-through
 anytime(Sys.Date())			# Date pass-through
 utcdate(Sys.Date())                     # Date pass-through
+
+cat("Next call will tickle exception\n")
 try(anytime(TRUE))                      # tickles unsupported type -- and exception, hence try()
+
+cat("All done!\n")
